==> bcc-core-api-node-sdk-1.6.0.tgz: package/lib/esm/test/countries.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { assert } from "chai";
import { client, countryUid, getDefaultConfig } from "./helpers";
import { Scope } from "../model/scopes";
import { CoreApiClient, ErrorCode } from "../api";
import { isCoreApiError } from "../model/error";
describe("Countries", () => __awaiter(void 0, void 0, void 0, function* () {
    it("Countries find", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.countries.find();
        const country = result.data.find((c) => c.nameEn === "Netherlands");
        if (!country)
            throw Error("Country not defined");
        assert.equal(country.uid, countryUid);
        assert.equal(country.nameNative, "Nederland");
        assert.equal(country.nameNo, "Nederland");
    }));
    it("Countries find with invalid scope", () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            const config = getDefaultConfig();
            config.scopes = [Scope.PersonsRead];
            const clientWithOutScope = new CoreApiClient(config);
            yield clientWithOutScope.countries.find();
            assert.fail("Was able to find with an invalid scope");
        }
        catch (err) {
            if (!isCoreApiError(err))
                throw Error("Invalid error type");
            assert.equal(err.details.code, ErrorCode.MissingScopes);
        }
    }));
}));

==> bcc-core-api-node-sdk-1.7.1.tgz: package/lib/esm/test/countries.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { assert } from "chai";
import { client, countryUid, getDefaultConfig } from "./helpers";
import { Scope } from "../model/scopes";
import { CoreApiClient, ErrorCode, isCoreApiError } from "../api";
describe("Countries", () => __awaiter(void 0, void 0, void 0, function* () {
    it("Countries find", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.countries.find();
        const country = result.data.find((c) => c.nameEn === "Netherlands");
        if (!country)
            throw Error("Country not defined");
        assert.equal(country.uid, countryUid);
        assert.equal(country.nameNative, "Nederland");
        assert.equal(country.nameNo, "Nederland");
    }));
    it("Countries find with invalid scope", () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            const config = getDefaultConfig();
            config.scopes = [Scope.PersonsRead];
            const clientWithOutScope = new CoreApiClient(config);
            yield clientWithOutScope.countries.find();
            assert.fail("Was able to find with an invalid scope");
        }
        catch (err) {
            if (!isCoreApiError(err))
                throw Error("Invalid error type");
            assert.equal(err.details.code, ErrorCode.MissingScopes);
        }
    }));
}));
